# Colab setup ------------------
import os, sys, subprocess
if "google.colab" in sys.modules:
    cmd = "pip install --upgrade xarray arviz cmdstanpy bebi103 watermark"
    process = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    stdout, stderr = process.communicate()
    data_path = "https://s3.amazonaws.com/bebi103.caltech.edu/data/"
else:
    data_path = "../data/"
# ------------------------------

import numpy as np
import pandas as pd

import holoviews as hv
hv.extension('bokeh')

import bebi103
bebi103.hv.set_defaults()

import ECDF

import bokeh.io
bokeh.io.output_notebook()

def label_vs_non_labeled_ecdf():
    df = pd.read_csv(os.path.join(data_path, 'gardner_time_to_catastrophe_dic_tidy.csv'))

    # Compute x and y values for ECDFs
    x_labeled, y_labeled = ecdf_vals(df.loc[df["labeled"], "time to catastrophe (s)"] / 60)
    x_unlabeled, y_unlabeled = ecdf_vals(
        df.loc[~df["labeled"], "time to catastrophe (s)"] / 60
    )

    # Make the plot
    p = bokeh.plotting.figure(
        plot_width=450,
        plot_height=300,
        x_axis_label="time to catastrophe (min)",
        y_axis_label="ECDF",
    )
    p.circle(x=x_labeled, y=y_labeled, legend_label="labeled")
    p.circle(x=x_unlabeled, y=y_unlabeled, color="orange", legend_label="unlabeled")
    p.legend.location = "bottom_right"

    return p


import numpy as np


def ecdf_vals(data):
    '''Generate the coordinates to plot an ECDF in "dots" style
        
        Parameters
        ----------
        data : Pandas Series or 1D Numpy array, containing tidy data for plotting
        
        Returns
        -------
        unique : returns the x values for plotting an ECDF
        norm_cum_counts : returns the y values for plotting an ECDF
        
    '''
    if len(np.shape(data)) > 1:
        raise RuntimeError('Input data must be one dimensional')
    
    unique, counts = np.unique(data, return_counts=True)
    norm_cum_counts = np.cumsum(counts) / np.sum(counts)
    
    return unique, norm_cum_counts


import setuptools

with open("README.md", "r") as f:
    long_description = f.read()

setuptools.setup(
    name='software_package_RK_BE103_Caltech',
    version='0.0.1',
    author='Rohit Kantipudi',
    author_email='rohitk@caltech.edu',
    description='Package created for extra-credit assignment be103a team 18 to analyze microtubule catastrophe.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    install_requires=["numpy","pandas", "bokeh>=1.4.0"],
    classifiers=(
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ),
)